@@ -26,7 +26,7 @@ class Day(object):
 
         Examples
         -------
-        >>> monday = Day(name = 'Monday')
+        >>> monday = Day(name='Monday')
         >>> curls = StaticExercise('Curls', '3 x 12')
         >>> monday.add_exercises(curls)
         >>> curls in monday.static_exercises
@@ -60,7 +60,7 @@ class Day(object):
 
         Examples
         -------
-        >>> monday = Day(name = 'Monday')
+        >>> monday = Day(name='Monday')
         >>> curls = StaticExercise('Curls', '3 x 12')
         >>> pulldowns = StaticExercise('Pulldowns', '4 x 10')
         >>> monday.add_exercises(curls, pulldowns)
@@ -72,6 +72,7 @@ class Day(object):
         for exercise in exercises:
             if isinstance(exercise, DynamicExercise):
                 self.dynamic_exercises.append(exercise)
+                exercise.day = self
 
             if isinstance(exercise, StaticExercise):
                 self.static_exercises.append(exercise)
@@ -105,6 +106,21 @@ class Day(object):
         )
         return out_str
 
+    def serialize(self):
+        """Export the object to a dictionary."""
+        result = {"name": self.name}
+        result["dynamic_exercises"] = [ex.serialize() for ex in self.dynamic_exercises]
+        result["static_exercises"] = [ex.serialize() for ex in self.static_exercises]
+        return result
+
+    @classmethod
+    def deserialize(cls, data):
+        """Create a new object from a dictionary."""
+        name = data["name"]
+        exercises = [DynamicExercise.deserialize(ex) for ex in data["dynamic_exercises"]]
+        exercises += [StaticExercise.deserialize(ex) for ex in data["static_exercises"]]
+        return cls(name, exercises)
+
 
 if __name__ == "__main__":
     import pytest
